@@ -19,7 +19,6 @@
  */
 
 #include "platform.h"
-#include "plibc.h"
 #include "extractor.h"
 #include <dirent.h>
 #include <sys/types.h>
@@ -670,7 +669,7 @@ EXTRACTOR_ltdl_init ()
   int err;
 
 #if ENABLE_NLS
-  BINDTEXTDOMAIN (PACKAGE, LOCALEDIR);
+  bindtextdomain (PACKAGE, LOCALEDIR);
 #endif
   err = lt_dlinit ();
   if (err > 0)
