@@ -146,7 +146,14 @@ main (int argc, char *argv[])
     fprintf (stderr, "failed to load test plugin\n");
     return 1;
   }
-  EXTRACTOR_extract (pl, "test_file.dat.bz2", NULL, 0, &process_replies,
+  if (0 != access ("test_file.dat.bz2",
+                   R_OK))
+    return 77;
+  EXTRACTOR_extract (pl,
+                     "test_file.dat.bz2",
+                     NULL,
+                     0,
+                     &process_replies,
                      "main-cls");
   EXTRACTOR_plugin_remove_all (pl);
   return ret;
