@@ -41,19 +41,20 @@ MODIFICATIONS.
    c - signed 8 bit value
    s - signed 16 bit value
    l - signed 32 bit value
+   x - signed 64 bit value
    p - (unpack only) value is a pointer to a pointer.  Generate the buffer
        to hold the data.
  */
+int
+EXTRACTOR_common_cat_unpack (const void *buf,
+                             const char *fmt,
+                             ...);
 
-int cat_pack(void * buf, const char *fmt, ... );
-
-int cat_unpack(const void * buf, const char *fmt, ... );
-
-struct cat_bvec {
+struct cat_bvec
+{
   unsigned long len;
-  void * data;
+  void *data;
 };
 
+
 #endif /* __CAT_PACK_H */
-
-
