@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the THUMBNAILGTKJ testcase.
  *
@@ -38,33 +37,32 @@ int
 main (int argc, char *argv[])
 {
   uint8_t thumbnail_data[] = { 137, 80, 78, 71 /* rest omitted */ };
-  struct SolutionData thumbnail_torsten_sol[] =
+  struct SolutionData thumbnail_torsten_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"1600x1200",
-	strlen ("1600x1200") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_THUMBNAIL,
-	EXTRACTOR_METAFORMAT_BINARY,
-	"image/png",
-	(void *) thumbnail_data, 
-	sizeof (thumbnail_data),
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "1600x1200",
+      strlen ("1600x1200") + 1,
+      0
+    },
     {
-      { "testdata/thumbnail_torsten.jpg",
-	thumbnail_torsten_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_THUMBNAIL,
+      EXTRACTOR_METAFORMAT_BINARY,
+      "image/png",
+      (void *) thumbnail_data,
+      sizeof (thumbnail_data),
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/thumbnail_torsten.jpg",
+      thumbnail_torsten_sol },
+    { NULL, NULL }
+  };
   return ET_main ("thumbnailgtk", ps);
 }
 
+
 /* end of test_thumbnailgtk.c */
